@@ -57,8 +57,7 @@ define([
         this.notebook = options.notebook;
         this.events = options.events;
         this.config = options.config;
-        this.notebook = options.notebook;
-        
+
         // we cannot put this as a class key as it has handle to "this".
         Cell.apply(this, [{
                     config: options.config, 
@@ -99,7 +98,7 @@ define([
             cell: this, 
             notebook: this.notebook});
         inner_cell.append(this.celltoolbar.element);
-        var input_area = $('<div/>').addClass('input_area');
+        var input_area = $('<div/>').addClass('input_area').attr("aria-label", i18n.msg._("Edit Markup Text here"));
         this.code_mirror = new CodeMirror(input_area.get(0), this._options.cm_config);
         // In case of bugs that put the keyboard manager into an inconsistent state,
         // ensure KM is enabled when CodeMirror is focused:
@@ -159,7 +158,7 @@ define([
     /**
      * setter: {{#crossLink "TextCell/set_text"}}{{/crossLink}}
      * @method get_text
-     * @retrun {string} CodeMirror current text value
+     * @return {string} CodeMirror current text value
      */
     TextCell.prototype.get_text = function() {
         return this.code_mirror.getValue();
@@ -249,8 +248,7 @@ define([
                 // HTML <img>)
                 var text = this.get_text();
                 marked(text, function (err, html) {
-                    html = security.sanitize_html(html);
-                    html = $($.parseHTML(html));
+                    html = $(security.sanitize_html_and_parse(html));
                     html.find('img[src^="attachment:"]').each(function (i, h) {
                         h = $(h);
                         var key = h.attr('src').replace(/^attachment:/, '');
@@ -397,14 +395,14 @@ define([
             var renderer = new marked.Renderer();
             renderer.tablecell = function (content, flags) {
               var type = flags.header ? 'th' : 'td';
-              var start_tag = '<' + type + '>';
+              var style = flags.align == null ? '': ' style="text-align: ' + flags.align + '"';
+              var start_tag = '<' + type + style + '>';
               var end_tag = '</' + type + '>\n';
               return start_tag + content + end_tag;
             };
             marked(text, { renderer: renderer }, function (err, html) {
                 html = mathjaxutils.replace_math(html, math);
-                html = security.sanitize_html(html);
-                html = $($.parseHTML(html));
+                html = $(security.sanitize_html_and_parse(html));
                 // add anchors to headings
                 html.find(":header").addBack(":header").each(function (i, h) {
                     h = $(h);
@@ -489,7 +487,7 @@ define([
 
         // We want to display a visual indicator that the drop is possible.
         // The dragleave event is fired when we hover a child element (which
-        // is often immediatly after we got the dragenter), so we keep track
+        // is often immediately after we got the dragenter), so we keep track
         // of the number of dragenter/dragleave we got, as discussed here :
         // https://stackoverflow.com/q/7110353/116067
         // This doesn't seem to be 100% reliable, so we clear the dropzone
