@@ -19,6 +19,9 @@ define([
      * Preliminary documentation for the REST API is at
      * https://github.com/ipython/ipython/wiki/IPEP-16%3A-Notebook-multi-directory-dashboard-and-URL-mapping#kernels-api
      * 
+     * Documentation for the messaging specifications is at
+     * https://jupyter-client.readthedocs.io/en/stable/messaging.html
+     *
      * @class Kernel
      * @param {string} kernel_service_url - the URL to access the kernel REST api
      * @param {string} ws_url - the websockets URL
@@ -151,7 +154,7 @@ define([
      *
      * @function list
      * @param {function} [success] - function executed on ajax success
-     * @param {function} [error] - functon executed on ajax error
+     * @param {function} [error] - function executed on ajax error
      */
     Kernel.prototype.list = function (success, error) {
         utils.ajax(this.kernel_service_url, {
@@ -177,7 +180,7 @@ define([
      * @function start
      * @param {params} [Object] - parameters to include in the query string
      * @param {function} [success] - function executed on ajax success
-     * @param {function} [error] - functon executed on ajax error
+     * @param {function} [error] - function executed on ajax error
      */
     Kernel.prototype.start = function (params, success, error) {
         var url = this.kernel_service_url;
@@ -217,7 +220,7 @@ define([
      *
      * @function get_info
      * @param {function} [success] - function executed on ajax success
-     * @param {function} [error] - functon executed on ajax error
+     * @param {function} [error] - function executed on ajax error
      */
     Kernel.prototype.get_info = function (success, error) {
         utils.ajax(this.kernel_url, {
@@ -235,13 +238,13 @@ define([
      *
      * Shutdown the kernel.
      *
-     * If you are also using sessions, then this function shoul NOT be
+     * If you are also using sessions, then this function should NOT be
      * used. Instead, use Session.delete. Otherwise, the session and
      * kernel WILL be out of sync.
      *
      * @function kill
      * @param {function} [success] - function executed on ajax success
-     * @param {function} [error] - functon executed on ajax error
+     * @param {function} [error] - function executed on ajax error
      */
     Kernel.prototype.kill = function (success, error) {
         this.events.trigger('kernel_killed.Kernel', {kernel: this});
@@ -263,7 +266,7 @@ define([
      *
      * @function interrupt
      * @param {function} [success] - function executed on ajax success
-     * @param {function} [error] - functon executed on ajax error
+     * @param {function} [error] - function executed on ajax error
      */
     Kernel.prototype.interrupt = function (success, error) {
         this.events.trigger('kernel_interrupting.Kernel', {kernel: this});
@@ -299,7 +302,7 @@ define([
          *
          * @function interrupt
          * @param {function} [success] - function executed on ajax success
-         * @param {function} [error] - functon executed on ajax error
+         * @param {function} [error] - function executed on ajax error
          */
         this.events.trigger('kernel_restarting.Kernel', {kernel: this});
         this.stop_channels();
@@ -467,33 +470,31 @@ define([
         
         var already_called_onclose = false; // only alert once
         var ws_closed_early = function(evt){
+            console.log("WebSocket closed early", evt);
             if (already_called_onclose){
                 return;
             }
             already_called_onclose = true;
-            if ( ! evt.wasClean ){
-                // If the websocket was closed early, that could mean
-                // that the kernel is actually dead. Try getting
-                // information about the kernel from the API call --
-                // if that fails, then assume the kernel is dead,
-                // otherwise just follow the typical websocket closed
-                // protocol.
-                that.get_info(function () {
-                    that._ws_closed(ws_host_url, false);
-                }, function () {
-                    that.events.trigger('kernel_dead.Kernel', {kernel: that});
-                    that._kernel_dead();
-                });
-            }
+            // If the websocket was closed early, that could mean
+            // that the kernel is actually dead. Try getting
+            // information about the kernel from the API call --
+            // if that fails, then assume the kernel is dead,
+            // otherwise just follow the typical websocket closed
+            // protocol.
+            that.get_info(function () {
+                that._ws_closed(ws_host_url, false);
+            }, function () {
+                that.events.trigger('kernel_dead.Kernel', {kernel: that});
+                that._kernel_dead();
+            });
         };
         var ws_closed_late = function(evt){
+            console.log("WebSocket closed unexpectedly", evt);
             if (already_called_onclose){
                 return;
             }
             already_called_onclose = true;
-            if ( ! evt.wasClean ){
-                that._ws_closed(ws_host_url, false);
-            }
+            that._ws_closed(ws_host_url, false);
         };
         var ws_error = function(evt){
             if (already_called_onclose){
@@ -736,7 +737,7 @@ define([
          *      @param callbacks.iopub.output {function}
          *      @param callbacks.iopub.clear_output {function}
          *      @param callbacks.input {function}
-         *      @param callbacks.clear_on_done=true {Bolean}
+         *      @param callbacks.clear_on_done=true {Boolean}
          * @param {object} [options]
          *      @param [options.silent=false] {Boolean}
          *      @param [options.user_expressions=empty_dict] {Dict}
@@ -771,7 +772,7 @@ define([
          *      }
          *
          * Each callback will be passed the entire message as a single
-         * arugment.  Payload handlers will be passed the corresponding
+         * argument.  Payload handlers will be passed the corresponding
          * payload and the execute_reply message.
          */
         var content = {
